# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: steammessages_gameservers.proto
# plugin: python-betterproto

from dataclasses import dataclass
from typing import List

import betterproto


@dataclass(eq=False, repr=False)
class CGameServersGetServerListRequest(betterproto.Message):
    filter: str = betterproto.string_field(1)
    limit: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class CGameServersGetServerListResponse(betterproto.Message):
    servers: List["CGameServersGetServerListResponseServer"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class CGameServersGetServerListResponseServer(betterproto.Message):
    addr: str = betterproto.string_field(1)
    gameport: int = betterproto.uint32_field(2)
    specport: int = betterproto.uint32_field(3)
    steamid: int = betterproto.fixed64_field(4)
    name: str = betterproto.string_field(5)
    appid: int = betterproto.uint32_field(6)
    gamedir: str = betterproto.string_field(7)
    version: str = betterproto.string_field(8)
    product: str = betterproto.string_field(9)
    region: int = betterproto.int32_field(10)
    players: int = betterproto.int32_field(11)
    max_players: int = betterproto.int32_field(12)
    bots: int = betterproto.int32_field(13)
    map: str = betterproto.string_field(14)
    secure: bool = betterproto.bool_field(15)
    dedicated: bool = betterproto.bool_field(16)
    os: str = betterproto.string_field(17)
    gametype: str = betterproto.string_field(18)


@dataclass(eq=False, repr=False)
class CGameServersGetServerSteamIDsByIpRequest(betterproto.Message):
    server_ips: List[str] = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class CGameServersIPsWithSteamIDsResponse(betterproto.Message):
    servers: List["CGameServersIPsWithSteamIDsResponseServer"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class CGameServersIPsWithSteamIDsResponseServer(betterproto.Message):
    addr: str = betterproto.string_field(1)
    steamid: int = betterproto.fixed64_field(2)


@dataclass(eq=False, repr=False)
class CGameServersGetServerIPsBySteamIdRequest(betterproto.Message):
    server_steamids: List[int] = betterproto.fixed64_field(1)
